_HELP = """Production-ready SDK for building AI applications.

**Quick start:**

* `ai-infra chat` — Start interactive chat
* `ai-infra chat -m "Hello"` — One-shot message
* `ai-infra providers` — List available providers
* `ai-infra models -p openai` — List models for a provider

More info: https://github.com/Aliikhatami94/ai-infra
"""
